<?php

namespace EventPortal\Domain\Event\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;

class Event extends Model
{
    use HasTable, AddToFillable, AddToCasts;

    public const KEY = 'event';

    /** @var string<string> */
    protected $dates = [
        'archived_at',
    ];

    /** @var array<string> */
    protected $fillable = [
        'name',
        'url',
        'status',
        'archived_at',
    ];

    /** @var array<string> */
    protected $casts = [
        'status' => 'array',
    ];

    public function delegates(): BelongsToMany
    {
        return $this->belongsToMany(Delegate::class);
    }

    public function archive(): void
    {
        $this->archived_at = now();
        $this->save();
    }

    public function unArchive(): void
    {
        $this->archived_at = null;
        $this->save();
    }
}
