<?php

namespace EventPortal\Http\Controllers\Admin\EventDelegate;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\Breadcrumb;
use Illuminate\Database\Query\JoinClause;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Inertia\Inertia;
use Inertia\Response;

class EventDelegateController
{
    public function index(Event $event): Response
    {
        $query = Delegate::query()
            ->join('delegate_event', function (JoinClause $query) {
                return $query->on('delegates.id', '=', 'delegate_event.delegate_id');
            })
            ->where('delegate_event.event_id', '=', $event->id);

        $table = Table::make('event-delegate.index')
            ->context($event)
            ->query($query)
            ->request(request())
            ->get();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('Delegates')
            ->get();

        return Inertia::render('EventDelegate/Index', [
            'data' => $table,
            'event' => $event,
            'breadcrumbs' => $breadcrumbs,
            'pageTitle' => 'Delegates',
        ]);
    }

    public function store(Request $request, Event $event): RedirectResponse
    {
        Form::make('delegate.create')
            ->model(new Delegate)
            ->context($event)
            ->validate($request->all())
            ->save($request->all());

        return redirect()->route('admin.event.delegate.index', $event);
    }

    public function show(Event $event, Delegate $delegate): Response
    {
        $delegateData = Form::make('event-delegate.show')
            ->model($delegate)
            ->context($event)
            ->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event))
            ->add('View Delegate')
            ->get();

        return Inertia::render('EventDelegate/Show', [
            'delegateData' => $delegateData,
            'breadcrumbs' => $breadcrumbs,
            'pageTitle' => $delegate->name,
        ]);
    }
}
